@@ -2,6 +2,7 @@ import logging
 
 import click
 
+import puddl
 from puddl.apps import App
 from puddl.conf import get_config
 
@@ -34,9 +35,13 @@ class AppsGroup(click.Group):
 @click.option('-l', '--log-level',
               type=click.Choice(LOG_LEVELS, case_sensitive=False),
               default='WARNING')
+@click.option('-d', '--debug', is_flag=True,
+              help='sets log level to DEBUG. ignores "--log-level"')
 @click.option('--loggers', default='', help='comma-separated logger names')
-@click.version_option()
-def root(log_level, loggers):
+@click.version_option(version=puddl.__version__)
+def root(log_level, debug, loggers):
+    if debug:
+        log_level = 'DEBUG'
     logging.basicConfig(level=log_level)
     if loggers:
         for name in loggers.split(','):
